==> kdotpy-1.0.2-py3-none-any.whl: kdotpy/kdotpy-batch.py <==
# kdotpy - k·p theory on a lattice for simulating semiconductor band structures
# Copyright (C) 2024, 2025 The kdotpy collaboration <kdotpy@uni-wuerzburg.de>
#
# SPDX-License-Identifier: GPL-3.0-only
#
# This file is part of kdotpy.
#
# kdotpy is free software: you can redistribute it and/or modify it under the
# terms of the GNU General Public License as published by the Free Software
# Foundation, version 3.
#
# kdotpy is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
# A PARTICULAR PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along with
# kdotpy. If not, see <https://www.gnu.org/licenses/>.
#
# Under Section 7 of GPL version 3 we require you to fulfill the following
# additional terms:
#
#     - We require the preservation of the full copyright notice and the license
#       in all original files.
#
#     - We prohibit misrepresentation of the origin of the original files. To
#       obtain the original files, please visit the Git repository at
#       <https://git.physik.uni-wuerzburg.de/kdotpy/kdotpy>
#
#     - As part of a scientific environment, we believe it is reasonable to
#       expect that you follow the rules of good scientific practice when using
#       kdotpy. In particular, we expect that you credit the original authors if
#       you benefit from this program, by citing our work, following the
#       citation instructions in the file CITATION.md bundled with kdotpy.
#
#     - If you make substantial changes to kdotpy, we strongly encourage that
#       you contribute to the original project by joining our team. If you use
#       or publish a modified version of this program, you are required to mark
#       your material in a reasonable way as different from the original
#       version.

import sys
from .parallel import parallel_apply_enumerate
from .config import initialize_config
from .batchtools import multi_values, replace_and_do_command, parse_batch_args, ncpu_nprocess


def main():
	initialize_config()
	allvar, allval, cmd, batchopts = parse_batch_args(sys.argv)
	ncpu, nprocess = ncpu_nprocess(cmd, **batchopts)

	# Initialize batch run
	print("Batch run")
	print("Press Ctrl-C to interrupt")
	exitstatuses = []

	# Get values and iterate (run the commands)
	val, strides = multi_values(*allval)
	exitstatuses = parallel_apply_enumerate(
		replace_and_do_command, val, f_args = (len(val), cmd, allvar, strides),
		description = "Running scripts", num_processes = nprocess,
		redefine_signals = False)

	# Finalize; show job status
	print("Done")
	# print ("Exit statuses:", exitstatuses)
	jobs_requested = len(val)
	jobs_run = len(exitstatuses)
	jobs_success = sum([1 if x == 0 else 0 for x in exitstatuses])
	excode = 1
	if jobs_success == jobs_requested:
		print("All jobs completed successfully")
		excode = 0
	elif jobs_success == 0:
		print("All jobs failed")
	elif jobs_run < jobs_requested:
		print("Some jobs did not start")
	else:
		print("Some jobs failed")
	print("Requested: %i  Run: %i  Success: %i  Failed: %i" % (jobs_requested, jobs_run, jobs_success, jobs_run - jobs_success))
	exit(excode)

if __name__ == '__main__':
	main()

==> kdotpy-1.2.0-py3-none-any.whl: kdotpy/kdotpy-batch.py <==
# kdotpy - k·p theory on a lattice for simulating semiconductor band structures
# Copyright (C) 2024, 2025 The kdotpy collaboration <kdotpy@uni-wuerzburg.de>
#
# SPDX-License-Identifier: GPL-3.0-only
#
# This file is part of kdotpy.
#
# kdotpy is free software: you can redistribute it and/or modify it under the
# terms of the GNU General Public License as published by the Free Software
# Foundation, version 3.
#
# kdotpy is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
# A PARTICULAR PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along with
# kdotpy. If not, see <https://www.gnu.org/licenses/>.
#
# Under Section 7 of GPL version 3 we require you to fulfill the following
# additional terms:
#
#     - We require the preservation of the full copyright notice and the license
#       in all original files.
#
#     - We prohibit misrepresentation of the origin of the original files. To
#       obtain the original files, please visit the Git repository at
#       <https://git.physik.uni-wuerzburg.de/kdotpy/kdotpy>
#
#     - As part of a scientific environment, we believe it is reasonable to
#       expect that you follow the rules of good scientific practice when using
#       kdotpy. In particular, we expect that you credit the original authors if
#       you benefit from this program, by citing our work, following the
#       citation instructions in the file CITATION.md bundled with kdotpy.
#
#     - If you make substantial changes to kdotpy, we strongly encourage that
#       you contribute to the original project by joining our team. If you use
#       or publish a modified version of this program, you are required to mark
#       your material in a reasonable way as different from the original
#       version.
import sys
from .parallel import parallel_apply_enumerate
from .config import initialize_config
from .batchtools import replace_and_do_command, parse_batch_args, ncpu_nprocess
from .batchtools import get_iterator_from_batchopts


def main():
	initialize_config()
	allvar, allval, cmd, batchopts = parse_batch_args(sys.argv)
	ncpu, nprocess = ncpu_nprocess(cmd, **batchopts)

	# Initialize batch run
	print("Batch run")
	print("Press Ctrl-C to interrupt")
	exitstatuses = []

	# Get iterator over the command replacement values and iterate (run the commands)
	batchiter = get_iterator_from_batchopts(allvar, allval, groups=batchopts.get('groups'))
	exitstatuses = parallel_apply_enumerate(
		replace_and_do_command, batchiter, f_args = (batchiter, cmd),
		description = "Running scripts", num_processes = nprocess,
		redefine_signals = False)

	# Finalize; show job status
	print("Done")
	# print ("Exit statuses:", exitstatuses)
	jobs_requested = len(batchiter)
	jobs_run = len(exitstatuses)
	jobs_success = sum([1 if x == 0 else 0 for x in exitstatuses])
	excode = 1
	if jobs_success == jobs_requested:
		print("All jobs completed successfully")
		excode = 0
	elif jobs_success == 0:
		print("All jobs failed")
	elif jobs_run < jobs_requested:
		print("Some jobs did not start")
	else:
		print("Some jobs failed")
	print("Requested: %i  Run: %i  Success: %i  Failed: %i" % (jobs_requested, jobs_run, jobs_success, jobs_run - jobs_success))
	exit(excode)

if __name__ == '__main__':
	main()
